summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codeclassfielddeclarationblock.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codeclassfielddeclarationblock.h')
-rw-r--r--umbrello/umbrello/codeclassfielddeclarationblock.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/codeclassfielddeclarationblock.h b/umbrello/umbrello/codeclassfielddeclarationblock.h
index add38fa8..3233c8f7 100644
--- a/umbrello/umbrello/codeclassfielddeclarationblock.h
+++ b/umbrello/umbrello/codeclassfielddeclarationblock.h
@@ -28,7 +28,7 @@ class CodeClassField;
* class CodeClassFieldDeclarationBlock
* Used to declare classifier fields (e.g. either class attributes or classifier
* associations) in the code document for any given code classfield. This is a
* special CodeBlockWithComments which is "sync'd" to the tqparent CodeClassField.
*/
class CodeClassFieldDeclarationBlock : public CodeBlockWithComments, public OwnedCodeBlock
@@ -44,7 +44,7 @@ public:
/**
* Constructor
*/
- CodeClassFieldDeclarationBlock (CodeClassField * tqparent);
+ CodeClassFieldDeclarationBlock (CodeClassField * parent);
/**
* Empty Destructor
@@ -57,11 +57,11 @@ public:
*/
CodeClassField * getParentClassField ( );
- /** A Utility method to get the tqparent object of the parentCodeClassfield
+ /** A Utility method to get the parent object of the parentCodeClassfield
*/
UMLObject * getParentObject ( );
// get the tqparent document
CodeDocument * getParentDocument ( );
/**
@@ -96,13 +96,13 @@ protected:
*/
virtual void updateContent() = 0;
// so tqparent can actually release this block
void forceRelease ();
private:
CodeClassField * m_parentclassfield;
- void init(CodeClassField * tqparent);
+ void init(CodeClassField * parent);
public slots:
@@ -28,7 +28,7 @@ class CodeClassField;
* Used to declare classifier fields (e.g. either class attributes or classifier
* associations) in the code document for any given code classfield. This is a
- * special CodeBlockWithComments which is "sync'd" to the tqparent CodeClassField.
+ * special CodeBlockWithComments which is "sync'd" to the parent CodeClassField.
*/
class CodeClassFieldDeclarationBlock : public CodeBlockWithComments, public OwnedCodeBlock
@@ -57,11 +57,11 @@ public:
*/
UMLObject * getParentObject ( );
- // get the tqparent document
+ // get the parent document
CodeDocument * getParentDocument ( );
/**
@@ -96,13 +96,13 @@ protected:
*/
virtual void updateContent() = 0;
- // so tqparent can actually release this block
+ // so parent can actually release this block
void forceRelease ();
private: